@@ -1,12 +1,14 @@
 /*
- * SPDX-FileCopyrightText: 2017 - 2022 UnionTech Software Technology Co., Ltd.  
+ * SPDX-FileCopyrightText: 2017 - 2023 UnionTech Software Technology Co., Ltd.
  * SPDX-License-Identifier: LGPL-3.0-or-later
  */
 #include "qdeepintheme.h"
 #include "qdeepinfiledialoghelper.h"
 #include "filedialogmanager_interface.h"
 #include "dthemesettings.h"
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include "../3rdparty/qdbustrayicon_p.h"
+#endif
 
 #include <DGuiApplicationHelper>
 #include <DPlatformTheme>
@@ -14,8 +16,6 @@
 #include <QGuiApplication>
 #include <QIconEnginePlugin>
 
-#include <XdgIcon>
-
 #include <private/qicon_p.h>
 #include <private/qiconloader_p.h>
 #define private public
@@ -32,6 +32,9 @@
 
 DGUI_USE_NAMESPACE
 
+#ifdef XDG_ICON_VERSION_MAR
+#include <XdgIcon>
+extern void updateXdgIconSystemTheme();
 #if XDG_ICON_VERSION_MAR >= 3
 namespace DEEPIN_QT_THEME {
 QThreadStorage<QString> colorScheme;
@@ -39,6 +42,7 @@ void(*setFollowColorScheme)(bool);
 bool(*followColorScheme)();
 }
 #endif
+#endif
 
 #define DISABLE_UPDATE_WINDOW_GEOMETRY "D_DISABLE_UPDATE_WINDOW_GEOMETRY_FOR_SCALE"
 #define DNOT_UPDATE_WINDOW_GEOMETRY "_d_disable_update_geometry_for_scale"
@@ -54,8 +58,7 @@ bool QDeepinTheme::m_usePlatformNativeDialog = true;
 QMimeDatabase QDeepinTheme::m_mimeDatabase;
 DThemeSettings *QDeepinTheme::m_settings = 0;
 
-extern void updateXdgIconSystemTheme();
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 static bool isDBusTrayAvailable() {
     static bool dbusTrayAvailable = false;
     static bool dbusTrayAvailableKnown = false;
@@ -68,12 +71,14 @@ static bool isDBusTrayAvailable() {
     }
     return dbusTrayAvailable;
 }
+#endif
 
 static void onIconThemeSetCallback()
 {
     QIconLoader::instance()->updateSystemTheme();
+#ifdef XDG_ICON_VERSION_MAR
     updateXdgIconSystemTheme();
-
+#endif
     if (qApp->inherits("Dtk::Widget::DApplication")) {
         // emit the signal: DApplication::iconThemeChanged
         qApp->metaObject()->invokeMethod(qApp, QT_STRINGIFY(iconThemeChanged));
@@ -89,13 +94,40 @@ static void onIconThemeSetCallback()
     }
 }
 
+static inline uint resolveMask(const QFont &f)
+{
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    return f.resolve();
+#else
+    return f.resolveMask();
+#endif
+}
+
+static inline void setResolveMask(QFont &f, uint mask)
+{
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    return f.resolve(mask);
+#else
+    return f.setResolveMask(mask);
+#endif
+}
+
 static void onFontChanged()
 {
+    // 插件中初始化 appFont 时会 resolve(0) 即清空 resolve_mask
+    // 如果用户再主动设置字体会改变 resolve_mask 即 app_font->resolve() > 0
+    // qApp->setFont(resolvedFont) 将不再响应 xsettings 字体变化
+    if (QGuiApplicationPrivate::app_font &&
+        resolveMask(*QGuiApplicationPrivate::app_font))
+        return;
+
     // 先清理旧的font对象
     if (QGuiApplicationPrivate::app_font)
         delete QGuiApplicationPrivate::app_font;
     QGuiApplicationPrivate::app_font = nullptr;
 
+    QFont appFont = qGuiApp->font(); // Refresh the font
+
     QEvent event(QEvent::ApplicationFontChange);
     qApp->sendEvent(qApp, &event);
 
@@ -108,7 +140,11 @@ static void onFontChanged()
     }
 
     qApp->sendEvent(DGuiApplicationHelper::instance(), &event);
-    Q_EMIT qGuiApp->fontChanged(qGuiApp->font());
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    Q_EMIT qGuiApp->fontChanged(appFont);
+#else
+    Q_UNUSED(appFont)
+#endif
 }
 
 static void updateWindowGeometry(QWindow *w)
@@ -347,8 +383,10 @@ static bool updateScaleLogcailDpi(const QPair<qreal, qreal> &dpi)
     } else if (qIsNull(dpi.second)) {
         QHighDpiScaling::m_logicalDpi.second = qGuiApp->primaryScreen()->handle()->logicalDpi().second;
     }
+#elif QT_VERSION < QT_VERSION_CHECK(6,0,0)
+    QHighDpiScaling::m_usePixelDensity = false; // Do not use dpi from platform plugin
 #else
-    QHighDpiScaling::m_usePixelDensity = false;
+    QHighDpiScaling::m_usePlatformPluginDpi = false; // Do not use dpi from platform plugin
 #endif
     return ok;
 }
@@ -417,6 +455,7 @@ static void onScreenScaleFactorsChanged(const QByteArray &value)
 
 static bool enabledRTScreenScale()
 {
+#if QT_VERSION < QT_VERSION_CHECK(6,0,0)
     // 应用中设置了和屏幕缩放相关的环境变量或启动相关属性后后不开启自动缩放功能
     static bool enable = !qEnvironmentVariableIsSet("D_DISABLE_RT_SCREEN_SCALE") &&
                             !qEnvironmentVariableIsSet("QT_DEVICE_PIXEL_RATIO") &&
@@ -426,6 +465,9 @@ static bool enabledRTScreenScale()
                             !QCoreApplication::testAttribute(Qt::AA_DisableHighDpiScaling) &&
                             !QCoreApplication::testAttribute(Qt::AA_EnableHighDpiScaling) &&
                             qGuiApp->platformName().endsWith("xcb");
+#else
+    static bool enable = false; // TODO What is the enable logic under Qt6 when Qt::AA_EnableHighDpiScaling is always true
+#endif
 
     return enable;
 }
@@ -518,21 +560,7 @@ static QIconEngine *createIconEngineWithKey(const QString &iconName, const QStri
 QIconEngine *QDeepinTheme::createIconEngine(const QString &iconName) const
 {
     QIconEngine *engine = createIconEngineWithKey(iconName, "DIconProxyEngine");
-    if (engine)
-        return engine;
-
-#ifdef DTHEMED_ICON_LOOKUP
-    if (iconName.contains("/"))
-        // handle Qt-standard paths.
-        return QGenericUnixTheme::createIconEngine(iconName);
-    else
-        return new DIconEngine(iconName);
-#elif XDG_ICON_VERSION_MAR < 3
-    return XdgIconEngineCreator::create(iconName);
-#else
-
-    return QGenericUnixTheme::createIconEngine(iconName);
-#endif
+    return engine ? engine : QGenericUnixTheme::createIconEngine(iconName);
 }
 
 QPixmap QDeepinTheme::standardPixmap(QPlatformTheme::StandardPixmap sp, const QSizeF &size) const
@@ -545,18 +573,18 @@ QIcon QDeepinTheme::fileIcon(const QFileInfo &fileInfo, QPlatformTheme::IconOpti
 {
     Q_UNUSED(iconOptions);
 
-    return XdgIcon::fromTheme(m_mimeDatabase.mimeTypeForFile(fileInfo).iconName());
+    return QIcon::fromTheme(m_mimeDatabase.mimeTypeForFile(fileInfo).iconName());
 }
 #else
 QPixmap QDeepinTheme::fileIconPixmap(const QFileInfo &fileInfo, const QSizeF &size, QPlatformTheme::IconOptions iconOptions) const
 {
     Q_UNUSED(iconOptions);
 
-    return XdgIcon::fromTheme(m_mimeDatabase.mimeTypeForFile(fileInfo).iconName()).pixmap(size.toSize());
+    return QIcon::fromTheme(m_mimeDatabase.mimeTypeForFile(fileInfo).iconName()).pixmap(size.toSize());
 }
 #endif
 
-#if !defined(QT_NO_DBUS) && !defined(QT_NO_SYSTEMTRAYICON)
+#if !defined(QT_NO_DBUS) && !defined(QT_NO_SYSTEMTRAYICON) && QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 QPlatformSystemTrayIcon *QDeepinTheme::createPlatformSystemTrayIcon() const
 {
     if (isDBusTrayAvailable())
@@ -605,6 +633,10 @@ QVariant QDeepinTheme::themeHint(QPlatformTheme::ThemeHint hint) const
         return true;
     case ShowShortcutsInContextMenus:
         return false;
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    case ButtonPressKeys:
+        return QVariant::fromValue(QList<Qt::Key>({ Qt::Key_Enter, Qt::Key_Return, Qt::Key_Space, Qt::Key_Select } ));
+#endif
     default:
         break;
     }
@@ -624,6 +656,14 @@ const QPalette *QDeepinTheme::palette(QPlatformTheme::Palette type) const
     return &palette;
 }
 
+static QFont *createUnresolveFont(const QString &family, qreal pointSize)
+{
+    auto font = new QFont(family);
+    font->setPointSizeF(pointSize);
+    setResolveMask(*font, QFont::NoPropertiesResolved);
+    return font;
+}
+
 const QFont *QDeepinTheme::font(QPlatformTheme::Font type) const
 {
     if (!qApp->desktopSettingsAware())
@@ -635,12 +675,16 @@ const QFont *QDeepinTheme::font(QPlatformTheme::Font type) const
             QByteArray font_name = theme->fontName();
             qreal font_size = 0;
 
+            static QScopedPointer<QFont> sysFont;
             if (font_name.isEmpty()) {
                 font_name = theme->gtkFontName();
                 int font_size_index = font_name.lastIndexOf(' ');
 
-                if (font_size_index <= 0)
-                    break;
+                if (font_size_index <= 0) {
+                    const QFont *defaultFont = QGenericUnixTheme::font(type);
+                    sysFont.reset(createUnresolveFont(defaultFont->family(), defaultFont->pointSizeF()));
+                    return sysFont.data();
+                }
 
                 font_size = font_name.mid(font_size_index + 1).toDouble();
                 font_name = font_name.left(font_size_index);
@@ -652,12 +696,8 @@ const QFont *QDeepinTheme::font(QPlatformTheme::Font type) const
                 font_size = 10.5;
             }
 
-            static QScopedPointer<QFont> sysFont;
-
             // We need to re-contruct a new QFont each time, inorder to refresh font dpi
-            sysFont.reset(new QFont(QString()));
-            sysFont->setFamily(font_name);
-            sysFont->setPointSizeF(font_size);
+            sysFont.reset(createUnresolveFont(font_name, font_size));
 
             return sysFont.data();
         }
@@ -667,8 +707,11 @@ const QFont *QDeepinTheme::font(QPlatformTheme::Font type) const
         if (DPlatformTheme *theme = appTheme()) {
             QByteArray font_name = theme->monoFontName();
 
+            static QScopedPointer<QFont> fixedFont;
             if (font_name.isEmpty()) {
-                break;
+                const QFont *defaultFont = QGenericUnixTheme::font(type);
+                fixedFont.reset(createUnresolveFont(defaultFont->family(), defaultFont->pointSizeF()));
+                return fixedFont.data();
             }
 
             qreal font_size = theme->fontPointSize();
@@ -677,12 +720,8 @@ const QFont *QDeepinTheme::font(QPlatformTheme::Font type) const
                 font_size = 10.5;
             }
 
-            static QScopedPointer<QFont> fixedFont;
-
             // We need to re-contruct a new QFont each time, inorder to refresh font dpi
-            fixedFont.reset(new QFont(QString()));
-            fixedFont->setFamily(font_name);
-            fixedFont->setPointSizeF(font_size);
+            fixedFont.reset(createUnresolveFont(font_name, font_size));
 
             return fixedFont.data();
         }
